# -*- python -*-
# pymode:lint_ignore=W0401,E501
"""Development settings and globals."""

from __future__ import absolute_import

from .base import *


########## DEBUG CONFIGURATION
# See: https://docs.djangoproject.com/en/dev/ref/settings/#debug
DEBUG = True

# See: https://docs.djangoproject.com/en/dev/ref/settings/#template-debug
TEMPLATE_DEBUG = DEBUG
########## END DEBUG CONFIGURATION


########## EMAIL CONFIGURATION
# See: https://docs.djangoproject.com/en/dev/ref/settings/#email-backend
EMAIL_BACKEND = 'django.core.mail.backends.console.EmailBackend'
########## END EMAIL CONFIGURATION


########## CACHE CONFIGURATION
# See: https://docs.djangoproject.com/en/dev/ref/settings/#caches
CACHES = {
    'default': {
        'BACKEND': 'django.core.cache.backends.locmem.LocMemCache',
    }
}
########## END CACHE CONFIGURATION


########## TOOLBAR CONFIGURATION
# See: http://django-debug-toolbar.readthedocs.org/en/latest/installation.html#explicit-setup
INSTALLED_APPS += (
    'debug_toolbar',
)

MIDDLEWARE_CLASSES += (
    'debug_toolbar.middleware.DebugToolbarMiddleware',
)

LOGGING['handlers'].update({
    'console': {
        'level': 'DEBUG',
        'class': 'logging.StreamHandler',
        'formatter': 'simple',
    }
})
LOGGING['loggers'].update({
    'gnuviechadmin': {
        'handlers': ['console'], 'level': 'DEBUG', 'propagate': True,},
    'dashboard': {
        'handlers': ['console'], 'level': 'DEBUG', 'propagate': True,},
    'domains': {
        'handlers': ['console'], 'level': 'DEBUG', 'propagate': True,},
    'gvacommon': {
        'handlers': ['console'], 'level': 'DEBUG', 'propagate': True,},
    'gvawebcore': {
        'handlers': ['console'], 'level': 'DEBUG', 'propagate': True,},
    'hostingpackages': {
        'handlers': ['console'], 'level': 'DEBUG', 'propagate': True,},
    'managemails': {
        'handlers': ['console'], 'level': 'DEBUG', 'propagate': True,},
    'osusers': {
        'handlers': ['console'], 'level': 'DEBUG', 'propagate': True,},
    'taskresults': {
        'handlers': ['console'], 'level': 'DEBUG', 'propagate': True,},
    'userdbs': {
        'handlers': ['console'], 'level': 'DEBUG', 'propagate': True,},
    'websites': {
        'handlers': ['console'], 'level': 'DEBUG', 'propagate': True,},
})

DEBUG_TOOLBAR_PATCH_SETTINGS = False

# http://django-debug-toolbar.readthedocs.org/en/latest/installation.html
INTERNAL_IPS = ('127.0.0.1', '10.0.2.2')
########## END TOOLBAR CONFIGURATION
